JournalAdmin

Trait JournalAdmin 

pub trait JournalAdmin:
    Send
    + Sync
    + 'static {
    // Required method
    fn name(&self) -> &str;

    // Provided methods
    fn list_persistence_ids<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = Vec<String>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait { ... }
    fn highest_sequence_nr_for<'life0, 'life1, 'async_trait>(
        &'life0 self,
        persistence_id: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = u64> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
    fn event_count_for<'life0, 'life1, 'async_trait>(
        &'life0 self,
        persistence_id: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = u64> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
}
Admin surface journals can implement to expose their contents to the dashboard. Default methods return empty vectors so implementing it is opt-in per backend.

Required Methods

fn name(&self) -> &str

Provided Methods

fn list_persistence_ids<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Vec<String>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn highest_sequence_nr_for<'life0, 'life1, 'async_trait>( &'life0 self, persistence_id: &'life1 str, ) -> Pin<Box<dyn Future<Output = u64> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn event_count_for<'life0, 'life1, 'async_trait>( &'life0 self, persistence_id: &'life1 str, ) -> Pin<Box<dyn Future<Output = u64> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Implementors